from django.utils import text, timezone


def get_date_filename(filename: str) -> str:
    """
    Get a filename containing the current date.

    filename = "HeLlO" → "2021-08-31-11-59-hello"
    filename = "why?is  this.pdf" → "2021-08-31-13-00-why-is-this.pdf"
    """
    dot_separated_values = filename.split(".")
    ending = dot_separated_values.pop() if len(dot_separated_values) > 1 else None
    filename_reconstructed = ".".join(dot_separated_values)
    filename_slug = text.slugify(filename_reconstructed)
    now = timezone.now().strftime("%Y-%m-%d-%H-%M")

    if ending:
        filename_slug += "." + ending

    return now + "-" + filename_slug
