# Generated by Django 3.2.4 on 2021-07-26 11:11

import django.contrib.sites.managers
from django.db import migrations, models
import django.db.models.deletion

import aleksis.core.managers


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ('core', '0019_fix_uniqueness_per_site'),
    ]

    operations = [
        migrations.CreateModel(
            name='AbiGroup',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
            ],
            options={
                'verbose_name': 'Group (Abi)',
                'verbose_name_plural': 'Groups (Abi)',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='AbiPerson',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('person', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='abi_persons', to='core.person', verbose_name='AlekSIS person')),
            ],
            options={
                'verbose_name': 'Person (Abi)',
                'verbose_name_plural': 'Persons (Abi)',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='RankingCategory',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('name', models.CharField(max_length=255, verbose_name='Name')),
                ('number_of_persons', models.PositiveIntegerField(default=1, verbose_name='Number of selectable persons')),
                ('group', models.ForeignKey(help_text='The persons in this group will be selectable for rankings in this category.', on_delete=django.db.models.deletion.CASCADE, related_name='ranking_categories', to='abi.abigroup', verbose_name='Group')),
            ],
            options={
                'verbose_name': 'Ranking category',
                'verbose_name_plural': 'Ranking categories',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='Ranking',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('weight', models.PositiveIntegerField(default=1, verbose_name='Weight of this ranking')),
                ('category', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='rankings', to='abi.rankingcategory', verbose_name='Ranking category')),
                ('person', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='rankings', to='abi.abiperson', verbose_name='Ranked persons')),
                ('ranked_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='done_rankings', to='abi.abiperson', verbose_name='Ranked by')),
            ],
            options={
                'verbose_name': 'Ranking',
                'verbose_name_plural': 'Rankings',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='Quote',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('text', models.TextField(help_text='You also can include any extra information here like a context if you want.', verbose_name='Quote')),
                ('authors', models.ManyToManyField(blank=True, help_text='This can be left empty if the author is unknown or if there is no specific author.', null=True, related_name='quotes', to='abi.AbiPerson', verbose_name='Author(s)')),
                ('submitted_by', models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='submitted_quotes', to='abi.abiperson', verbose_name='Submitted by')),
            ],
            options={
                'verbose_name': 'Quote',
                'verbose_name_plural': 'Quotes',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='Profile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('nickname', models.CharField(blank=True, max_length=255, verbose_name='Nickname')),
                ('current_picture', models.ImageField(blank=True, null=True, upload_to='abi/current/', verbose_name='Current picture')),
                ('old_picture', models.ImageField(blank=True, null=True, upload_to='abi/old/', verbose_name='Picture from the childhood')),
                ('person', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='profile', to='abi.abiperson', verbose_name='Person')),
            ],
            options={
                'verbose_name': 'Personal profile',
                'verbose_name_plural': 'Personal profiles',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.CreateModel(
            name='Comment',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('extended_data', models.JSONField(default=dict, editable=False)),
                ('text', models.TextField(blank=True, verbose_name='Comment')),
                ('requested', models.BooleanField(default=False, verbose_name='Requested')),
                ('author', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='written_comments', to='abi.abiperson', verbose_name='Author')),
                ('person', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='received_comments', to='abi.abiperson', verbose_name='Receiver')),
            ],
            options={
                'verbose_name': 'Comment',
                'verbose_name_plural': 'Comments',
            },
            managers=[
                ('objects', aleksis.core.managers.AlekSISBaseManager()),
            ],
        ),
        migrations.AddField(
            model_name='abigroup',
            name='members',
            field=models.ManyToManyField(blank=True, null=True, related_name='member_of', to='abi.AbiPerson', verbose_name='Group members'),
        ),
    ]
