from rules import add_perm, predicate

from aleksis.apps.abi.models import AbiGroup, Comment, Quote
from aleksis.core.util.predicates import (
    has_any_object,
    has_global_perm,
    has_object_perm,
    has_person,
)


@predicate
def has_abi_person(user):
    return bool(getattr(user.person, "abi_person", None))


@predicate
def is_own_profile(user, obj):
    if not obj:
        return True
    return user.person == obj.person.person


# View abi person list
view_abipersons_predicate = has_person & has_global_perm("abi.view_abiperson")
add_perm("abi.view_abipersons_rule", view_abipersons_predicate)

# Add abi person
add_abiperson_predicate = view_abipersons_predicate & has_global_perm("abi.add_abiperson")
add_perm("abi.add_abiperson_rule", add_abiperson_predicate)

# View abi person
view_abiperson_predicate = view_abipersons_predicate
add_perm("abi.view_abiperson_rule", view_abiperson_predicate)

# Edit abi person
edit_abiperson_predicate = view_abipersons_predicate & has_global_perm("abi.change_abiperson")
add_perm("abi.edit_abiperson_rule", edit_abiperson_predicate)

# Delete abi person
delete_abiperson_predicate = view_abipersons_predicate & has_global_perm("abi.delete_abiperson")
add_perm("abi.delete_abiperson_rule", delete_abiperson_predicate)

# View abi group list
view_abigroups_predicate = has_person & has_global_perm("abi.view_abigroup")
add_perm("abi.view_abigroups_rule", view_abigroups_predicate)

# Add abi group
add_abigroup_predicate = view_abigroups_predicate & has_global_perm("abi.add_abigroup")
add_perm("abi.add_abigroup_rule", add_abigroup_predicate)

# Edit abi group
edit_abigroup_predicate = view_abigroups_predicate & has_global_perm("abi.change_abigroup")
add_perm("abi.edit_abigroup_rule", edit_abigroup_predicate)

# Delete abi group
delete_abigroup_predicate = view_abigroups_predicate & has_global_perm("abi.delete_abigroup")
add_perm("abi.delete_abigroup_rule", delete_abigroup_predicate)

# View ranking category list
view_rankingcategories_predicate = has_person & has_global_perm("abi.view_rankingcategory")
add_perm("abi.view_rankingcategories_rule", view_rankingcategories_predicate)

# Add ranking category
add_rankingcategory_predicate = view_rankingcategories_predicate & has_global_perm(
    "abi.add_rankingcategory"
)
add_perm("abi.add_rankingcategory_rule", add_rankingcategory_predicate)

# Edit ranking category
edit_rankingcategory_predicate = view_rankingcategories_predicate & has_global_perm(
    "abi.change_rankingcategory"
)
add_perm("abi.edit_rankingcategory_rule", edit_rankingcategory_predicate)

# Delete ranking category
delete_rankingcategory_predicate = view_rankingcategories_predicate & has_global_perm(
    "abi.delete_rankingcategory"
)
add_perm("abi.delete_rankingcategory_rule", delete_rankingcategory_predicate)

# Fill out profile
edit_profile_predicate = (
    has_person
    & has_abi_person
    & (
        (has_global_perm("abi.use_profile") & is_own_profile)
        | has_global_perm("abi.change_profile")
    )
)
add_perm("abi.use_profile_rule", edit_profile_predicate)

# Edit profile questions
edit_profile_questions_predicate = (
    has_person & has_abi_person & has_global_perm("abi.change_additionalprofilefield")
)
add_perm("abi.edit_profile_questions_rule", edit_profile_questions_predicate)


# Rank persons
rank_persons_predicate = has_person & has_abi_person & has_global_perm("abi.rank_persons")
add_perm("abi.rank_persons_rule", rank_persons_predicate)


# Add comment
add_comment_predicate = (
    has_person
    & has_abi_person
    & (
        has_global_perm("abi.add_comment")
        | has_any_object("abi.write_comment_for", AbiGroup)
        | has_any_object("abi.write_comment_for_with_review", AbiGroup)
    )
)
add_perm("abi.add_comment_rule", add_comment_predicate)


# View own comments
view_comments_predicate = add_comment_predicate | (
    has_person & has_abi_person & has_any_object("abi.view_comment", Comment)
)
add_perm("abi.view_comments_rule", view_comments_predicate)


@predicate
def comment_is_for_person(user, obj):
    return obj.person == user.person.abi_person


@predicate
def is_reviewable(user, obj):
    return obj.needs_review and not obj.reviewed


review_comment_predicate = has_person & has_abi_person & comment_is_for_person & is_reviewable
add_perm("abi.review_comment_rule", review_comment_predicate)

# Edit comment
edit_comment_predicate = view_comments_predicate & (
    has_global_perm("abi.change_comment") | has_object_perm("abi.change_comment")
)
add_perm("abi.edit_comment_rule", edit_comment_predicate)

# Delete comment
delete_comment_predicate = view_comments_predicate & (
    has_global_perm("abi.delete_comment") | has_object_perm("abi.delete_comment")
)
add_perm("abi.delete_comment_rule", delete_comment_predicate)

# Add quotes
create_quote_rule = has_person & has_global_perm("abi.create_quote")
add_perm("abi.create_quote_rule", create_quote_rule)

# Edit quotes
edit_quote_predicate = has_person & (
    has_global_perm("abi.change_quote") | has_object_perm("abi.change_quote")
)
add_perm("abi.edit_quote_rule", edit_quote_predicate)

# Delete quotes
delete_quote_predicate = has_person & (
    has_global_perm("abi.delete_quote") | has_object_perm("abi.delete_quote")
)
add_perm("abi.delete_quote_rule", delete_quote_predicate)

# List all quotes
view_quotes_predicate = has_person & has_abi_person & has_global_perm("abi.view_quote")
add_perm("abi.view_quotes_rule", view_quotes_predicate)

# Suggest quotes
suggest_quote_predicate = has_person & has_abi_person & has_global_perm("abi.suggest_quote")
add_perm("abi.suggest_quote_rule", suggest_quote_predicate)

# View suggested quotes
view_suggested_quotes_predicate = (
    has_person
    & has_abi_person
    & (has_global_perm("abi.suggest_quote") | has_any_object("abi.view_quote", Quote))
)
add_perm("abi.view_suggested_quotes_rule", view_suggested_quotes_predicate)

add_perm(
    "abi.view_abi_menu",
    has_person
    & has_abi_person
    & (
        view_abipersons_predicate
        | view_abigroups_predicate
        | view_rankingcategories_predicate
        | rank_persons_predicate
        | edit_profile_predicate
        | edit_profile_questions_predicate
        | view_quotes_predicate
        | suggest_quote_predicate
        | view_comments_predicate
    ),
)
# Export profiles
export_profiles_predicate = has_person & view_abipersons_predicate
add_perm("abi.export_profiles_rule", export_profiles_predicate)

# Export rankings
export_rankings_predicate = has_person & view_abipersons_predicate
add_perm("abi.export_rankings_rule", export_rankings_predicate)

# Export quotes
export_quotes_predicate = has_person & view_quotes_predicate
add_perm("abi.export_quotes_rule", export_quotes_predicate)

# Export comments
export_comments_predicate = has_person & has_global_perm("abi.view_comment")
add_perm("abi.export_comments_rule", export_comments_predicate)


export_predicate = (
    export_profiles_predicate
    | export_rankings_predicate
    | export_quotes_predicate
    | export_comments_predicate
)
add_perm("abi.export_rule", export_predicate)
