import os
import tempfile
import zipfile

from django.utils.text import slugify

from aleksis.core.util.celery_progress import ProgressRecorder, recorded_task

from .models import ExportedPictures, Profile


@recorded_task
def export_pictures(recorder: ProgressRecorder):
    with tempfile.TemporaryDirectory() as tmp_dir:
        zip_path = os.path.join(tmp_dir, "pictures.zip")
        zip_file = zipfile.ZipFile(zip_path, "w")

        picture_attrs = [
            "current_picture",
            "old_picture",
            "additional_picture_1",
            "additional_picture_2",
        ]

        for profile in recorder.iterate(Profile.objects.all()):
            prefix = slugify(profile.person.name)
            for attr in picture_attrs:
                picture = getattr(profile, attr, None)
                if picture:
                    ext = os.path.splitext(picture.name)[1]
                    picture_path = os.path.join("pictures", f"{prefix}_{attr}{ext}")
                    zip_file.write(picture.path, picture_path)

        zip_file.close()

        with open(zip_path, "rb") as f:
            ExportedPictures.save_file(f)
