from django.urls import path

from . import views

urlpatterns = [
    path("persons/", views.AbiPersonListView.as_view(), name="abi_persons"),
    path(
        "persons/create/",
        views.AbiPersonCreateView.as_view(),
        name="create_abi_person",
    ),
    path(
        "persons/<int:pk>/",
        views.AbiPersonDetailView.as_view(),
        name="abi_person",
    ),
    path(
        "persons/<int:pk>/edit/",
        views.AbiPersonEditView.as_view(),
        name="edit_abi_person",
    ),
    path(
        "persons/<int:pk>/delete/",
        views.AbiPersonDeleteView.as_view(),
        name="delete_abi_person",
    ),
    path("groups/", views.AbiGroupListView.as_view(), name="abi_groups"),
    path(
        "groups/create/",
        views.AbiGroupCreateView.as_view(),
        name="create_abi_group",
    ),
    path(
        "groups/<int:pk>/edit/",
        views.AbiGroupEditView.as_view(),
        name="edit_abi_group",
    ),
    path(
        "groups/<int:pk>/delete/",
        views.AbiGroupDeleteView.as_view(),
        name="delete_abi_group",
    ),
    path(
        "groups/import/",
        views.AbiGroupImportView.as_view(),
        name="import_abi_group",
    ),
    path("ranking/categories/", views.RankingCategoryListView.as_view(), name="ranking_categories"),
    path(
        "ranking/categories/create/",
        views.RankingCategoryCreateView.as_view(),
        name="create_ranking_category",
    ),
    path(
        "ranking/categories/<int:pk>/edit/",
        views.RankingCategoryEditView.as_view(),
        name="edit_ranking_category",
    ),
    path(
        "ranking/categories/<int:pk>/delete/",
        views.RankingCategoryDeleteView.as_view(),
        name="delete_ranking_category",
    ),
    path(
        "ranking/",
        views.RankingFormView.as_view(),
        name="ranking_form",
    ),
    path(
        "comments/",
        views.CommentListView.as_view(),
        name="comments",
    ),
    path(
        "comments/create/",
        views.CommentCreateView.as_view(),
        name="create_comment",
    ),
    path(
        "comments/<int:pk>/edit/",
        views.CommentEditView.as_view(),
        name="edit_comment",
    ),
    path(
        "comments/<int:pk>/delete/",
        views.CommentDeleteView.as_view(),
        name="delete_comment",
    ),
    path(
        "comments/<int:pk>/review/yes/",
        views.CommentReviewView.as_view(),
        {"accept": True},
        name="review_comment_yes",
    ),
    path(
        "comments/<int:pk>/review/no/",
        views.CommentReviewView.as_view(),
        {"accept": False},
        name="review_comment_no",
    ),
    path("profile/", views.ProfileView.as_view(), name="update_profile"),
    path("profile/<int:pk>/", views.ProfileView.as_view(), name="update_profile"),
    path("profile/configure/", views.ConfigureProfileView.as_view(), name="configure_profile"),
    path("quotes/my/", views.MyQuotesListView.as_view(), name="my_quotes"),
    path("quotes/suggest/", views.SuggestQuoteView.as_view(), name="suggest_quote"),
    path("quotes/", views.QuotesListView.as_view(), name="quotes"),
    path("quotes/create/", views.CreateQuoteView.as_view(), name="create_quote"),
    path("quote/<int:pk>/edit/", views.QuoteEditView.as_view(), name="edit_quote"),
    path("quote/<int:pk>/delete/", views.QuoteDeleteView.as_view(), name="delete_quote"),
    path("export/", views.ExportOverviewView.as_view(), name="export_overview"),
    path("export/comment/", views.CommentExportView.as_view(), name="export_comment"),
    path("export/profile/", views.ProfileExportView.as_view(), name="export_profile"),
    path("export/quote/", views.QuoteExportView.as_view(), name="export_quote"),
    path("export/ranking/", views.RankingExportView.as_view(), name="export_ranking"),
    path("export/picture/", views.PictureExportView.as_view(), name="export_picture"),
    path(
        "export/picture/pictures.zip",
        views.GetExportedPicturesView.as_view(),
        name="get_exported_pictures",
    ),
]
